%define ALD_Ver		2.0
%define PythonVer 3.10

%define OrgName meson
Name:         python%{PythonVer}-%{OrgName}

License:      Apache License, Version 2.0
Summary:      A high performance build system
Group:        Development/Libraries
Version:      0.64.1
Release:      0
BuildArch:    noarch
Url: https://mesonbuild.com

#https://github.com/mesonbuild/meson/releases

Source: %{OrgName}-%{version}.tar.xz
Source2: %{OrgName}-%{version}-patches.tgz

Provides: %{OrgName}
Requires: python%{PythonVer}
# -----------------------------------------------------

%define AktPythonVer	%(v=`python3 -V`; v=${v#* } ; v=${v%.*} ; echo "$v")
%define purelib		/usr/lib/python%{AktPythonVer}/site-packages
%define rpmmacrodir	%{_rpmconfigdir}/macros.d

%if "%{AktPythonVer}" != "%{PythonVer}"
ERROR: %{AktPythonVer} %{PythonVer}
exit 1
%endif

%define DestDir		/Compiler/python/%{PythonVer}
%define _srcrpmdir	%{_topdir}/SRPMS/%{ALD_Ver}

# -----------------------------------------------------
%define auto_local %{_sourcedir}/AUTO_LOCAL-1.sh
%define have_auto_local %(if test -x %{auto_local} ; then echo 1 ; else echo 0 ; fi)

# ------------------- description ------------------------------------
%description
Meson is a cross-platform build system designed to be both as fast and as user friendly as possible. It supports many languages and compilers, including GCC, Clang, PGI, Intel, and Visual Studio. Its build definitions are written in a simple non-Turing complete DSL.
#-------------------------------
%package py
Summary:      %{OrgName}-%{PythonVer} source
Requires:     %{name} = %{version}
%description py
These libraries are needed to compile python3 code.

# ------------------- setup ------------------------------------------
%Prep
%setup -q -n %{OrgName}-%{version}

tar -xaf %SOURCE2
patch -p0<patches/flags.patch
patch -p0<patches/no_rpath.patch

sed -i -e "/^%%__meson /s| .*$| %{_bindir}/%{OrgName}|" data/macros.meson

# ------------------- Build ------------------------------------------
%Build
python3 setup.py build &>FMake_log.txt

# ------------------- Install ----------------------------------------
%install

rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT
mkdir -p %{_srcrpmdir}

python3 setup.py install \
	--single-version-externally-managed \
	--root=$RPM_BUILD_ROOT \
	&>Finstall_log.txt

mkdir -p $RPM_BUILD_ROOT%{rpmmacrodir}
cp -a data/macros.meson $RPM_BUILD_ROOT%{rpmmacrodir}/
rm $RPM_BUILD_ROOT%{purelib}/meson-%{version}-py%{PythonVer}.egg-info/SOURCES.txt

%{_rpmconfigdir}/python_install_opti.sh %{PythonVer} %{purelib} 

# ------------------- Clean ------------------------------------------
%Clean

%if %{have_auto_local}
  %{auto_local} -build_cpu=%{_build_cpu} -target_cpu=%{_target_cpu} \
	-ALD_Ver=%{ALD_Ver} -RpmMovePath=%{DestDir} -tar_arg=bzip2
%endif  # have_auto_local

# ------------------- Files ------------------------------------------
%Files
%{rpmmacrodir}/macros.meson
%{_bindir}/meson

%{purelib}/meson-%{version}-py%{PythonVer}.egg-info

%dir %{purelib}/mesonbuild
%{purelib}/mesonbuild/*.pyc

%dir %{purelib}/mesonbuild/ast
%{purelib}/mesonbuild/ast/*.pyc
%dir %{purelib}/mesonbuild/backend
%{purelib}/mesonbuild/backend/*.pyc

%dir %{purelib}/mesonbuild/cmake
%{purelib}/mesonbuild/cmake/*.pyc
%dir %{purelib}/mesonbuild/cmake/data
%{purelib}/mesonbuild/cmake/data/*.pyc
%{purelib}/mesonbuild/cmake/data/preload.cmake

%dir %{purelib}/mesonbuild/compilers
%{purelib}/mesonbuild/compilers/*.pyc
%dir %{purelib}/mesonbuild/compilers/mixins
%{purelib}/mesonbuild/compilers/mixins/*.pyc

%dir %{purelib}/mesonbuild/dependencies
%{purelib}/mesonbuild/dependencies/*.pyc
%dir %{purelib}/mesonbuild/dependencies/data
%{purelib}/mesonbuild/dependencies/data/*.pyc
%{purelib}/mesonbuild/dependencies/data/*.txt

%dir %{purelib}/mesonbuild/interpreter
%{purelib}/mesonbuild/interpreter/*.pyc
%dir %{purelib}/mesonbuild/interpreter/primitives
%{purelib}/mesonbuild/interpreter/primitives/*.pyc

%dir %{purelib}/mesonbuild/interpreterbase/
%{purelib}/mesonbuild/interpreterbase/*.pyc

%dir %{purelib}/mesonbuild/linkers/
%{purelib}/mesonbuild/linkers/*.pyc

%dir %{purelib}/mesonbuild/modules
%{purelib}/mesonbuild/modules/*.pyc

%dir %{purelib}/mesonbuild/scripts
%{purelib}/mesonbuild/scripts/*.pyc
%{purelib}/mesonbuild/scripts/cmd_or_ps.ps1

%dir %{purelib}/mesonbuild/templates
%{purelib}/mesonbuild/templates/*.pyc

%dir %{purelib}/mesonbuild/utils/
%{purelib}/mesonbuild/utils/*.pyc

%dir %{purelib}/mesonbuild/wrap
%{purelib}/mesonbuild/wrap/*.pyc
%{_mandir}/man1

%files py
%{purelib}/mesonbuild/*.py
%{purelib}/mesonbuild/*/*.py
%{purelib}/mesonbuild/*/*/*.py
%{_datadir}/polkit-1
